@@ -39,7 +39,7 @@ MailFolder MailFolder::accessFolder(const std::string& path)
 }
 
 
-void MailFolder::enumerateFolders(const string& path, Consumer<MailFolder>& cons)
+void MailFolder::enumerateFolders(const std::string& path, Consumer<MailFolder>& cons)
 {
 //	fprintf(stderr, "enumerating mailboxes\n");
 	MailboxMailFolder::enumerateFolders(path, cons);
