@@ -1,8 +1,6 @@
 #ifndef MAILBOXMAILFOLDER_H
 #define MAILBOXMAILFOLDER_H
 
-#pragma interface
-
 /*
  * Mailbox mail folder access
  *
@@ -26,6 +24,8 @@
 #include <buffy/MailFolder.h>
 #include <string>
 
+namespace buffy {
+
 class MailboxMailFolder : public MailFolderImpl
 {
 protected:
@@ -36,6 +36,7 @@ protected:
 	int _stat_new;
 	int _stat_flagged;
 	int _mbox_mtime;
+	int _mbox_size;
 	int _deleted;
 	
 public:
@@ -55,8 +56,11 @@ public:
 	virtual bool changed();
 	virtual void updateStatistics();
 
+	static MailFolder accessFolder(const std::string& path);
 	static void enumerateFolders(const std::string& dir, MailFolderConsumer& cons);
 };
 
+}
+
 // vim:set ts=4 sw=4:
 #endif
